# AllenNLP-Hydra

Plugin For [AllenNLP](https://github.com/allenai/allennlp) that enables 
composing configs through the use of the 
[Hydra Library from Facebook Research](https://github.com/facebookresearch/hydra).

**NOTE** there is no affiliation between this project and AllenNLP or the Allen 
Institute for AI.

We use the same 
[contributions guideline](https://github.com/gabeorlanski/allennlp-hydra/blob/master/CONTRIBUTING.md) 
as AllenNLP in order to maintain similar code styles. For this reason [our style 
guide](https://github.com/gabeorlanski/allennlp-hydra/blob/master/STYLE.md) is 
the same as [that found in their repository](https://github.com/allenai/allennlp/blob/main/STYLE.md).


# Install Instructions

Clone the repo

```shell
pip install .
echo allennlp_hydra >> ~.allennlp_plugins
```

The second line adds `allennlp-hydra` to the allennlp plugins file so that it 
can globally be recognized.

# Basic Guide

Coming soon